# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import winrt.system
from winrt import _winrt_microsoft_windows_widgets_providers

__all__ = [
    "WidgetActionInvokedArgs",
    "WidgetAnalyticsInfoReportedArgs",
    "WidgetContext",
    "WidgetContextChangedArgs",
    "WidgetCustomizationRequestedArgs",
    "WidgetErrorInfoReportedArgs",
    "WidgetInfo",
    "WidgetManager",
    "WidgetUpdateRequestOptions",
    "IWidgetManager",
    "IWidgetProvider",
    "IWidgetProvider2",
    "IWidgetProviderAnalytics",
    "IWidgetProviderErrors",
]

WidgetActionInvokedArgs = _winrt_microsoft_windows_widgets_providers.WidgetActionInvokedArgs
WidgetAnalyticsInfoReportedArgs = _winrt_microsoft_windows_widgets_providers.WidgetAnalyticsInfoReportedArgs
WidgetContext = _winrt_microsoft_windows_widgets_providers.WidgetContext
WidgetContextChangedArgs = _winrt_microsoft_windows_widgets_providers.WidgetContextChangedArgs
WidgetCustomizationRequestedArgs = _winrt_microsoft_windows_widgets_providers.WidgetCustomizationRequestedArgs
WidgetErrorInfoReportedArgs = _winrt_microsoft_windows_widgets_providers.WidgetErrorInfoReportedArgs
WidgetInfo = _winrt_microsoft_windows_widgets_providers.WidgetInfo
WidgetManager = _winrt_microsoft_windows_widgets_providers.WidgetManager
WidgetUpdateRequestOptions = _winrt_microsoft_windows_widgets_providers.WidgetUpdateRequestOptions
IWidgetManager = _winrt_microsoft_windows_widgets_providers.IWidgetManager
IWidgetProvider = _winrt_microsoft_windows_widgets_providers.IWidgetProvider
IWidgetProvider2 = _winrt_microsoft_windows_widgets_providers.IWidgetProvider2
IWidgetProviderAnalytics = _winrt_microsoft_windows_widgets_providers.IWidgetProviderAnalytics
IWidgetProviderErrors = _winrt_microsoft_windows_widgets_providers.IWidgetProviderErrors
